@@ -7,6 +7,9 @@ try:
         EthereumBlock,
         EthereumLabel,
         EthereumTransaction,
+        MumbaiBlock,
+        MumbaiLabel,
+        MumbaiTransaction,
         PolygonBlock,
         PolygonLabel,
         PolygonTransaction,
@@ -30,6 +33,11 @@ MODELS: Dict[Network, Dict[str, Base]] = {
         "labels": EthereumLabel,
         "transactions": EthereumTransaction,
     },
+    Network.mumbai: {
+        "blocks": MumbaiBlock,
+        "labels": MumbaiLabel,
+        "transactions": MumbaiTransaction,
+    },
     Network.polygon: {
         "blocks": PolygonBlock,
         "labels": PolygonLabel,
